

<img src="https://github.com/IFCA/caso/raw/master/doc/source/static/caso.png" width="300">

[![Python TestingTravis](https://img.shields.io/github/actions/workflow/status/IFCA/caso/python-test.yml)](https://github.com/IFCA/caso/actions/workflows/python-test.yml)
[![Coveralls](https://img.shields.io/coveralls/IFCA/caso.svg)](https://coveralls.io/github/IFCA/caso)
[![PyPI](https://img.shields.io/pypi/v/caso.svg)](https://pypi.python.org/pypi/caso)
[![Python versions](https://img.shields.io/pypi/pyversions/caso.svg)](https://pypi.python.org/pypi/caso)

cASO is an OpenStack Accounting extractor.

* Free software: Apache license
* Source: https://github.com/IFCA/caso
* Bugs: https://github.com/IFCA/caso/issues

<img src="https://github.com/IFCA/caso/raw/master/doc/source/static/caso-diagram.png" width="500">

Documentation (the source is in ``doc/source/``) is online at
[caso documentation](https://caso.readthedocs.org/en/latest/).

## Acknowledgement

This work is co-funded by the [EOSC-hub project](http://eosc-hub.eu/) (Horizon 2020) under Grant number 777536.
<img src="https://wiki.eosc-hub.eu/download/attachments/1867786/eu%20logo.jpeg?version=1&modificationDate=1459256840098&api=v2" height="24">
<img src="https://wiki.eosc-hub.eu/download/attachments/18973612/eosc-hub-web.png?version=1&modificationDate=1516099993132&api=v2" height="24">
